#
# spec file for package scpm
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           scpm
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  xz
BuildRequires:  pkgconfig(cryptopp)
%if 0%{suse_version} > 1220
BuildRequires:  makeinfo
%endif
Summary:        System Configuration Profile Management
License:        GPL-2.0+
Group:          System/Base
Version:        1.1.7
Release:        2.3
Source:         %{name}-%{version}.tar.xz
Source1:        logrotate-scpm
Patch1:         scpm-fix_boot_script.patch
Patch2:         scpm-1.1.7-gcc44.patch
Patch3:         scpm-1.1.7-no_static_linking.patch
Patch4:         scpm-fix_link_order.patch
Patch5:         scpm-header.patch
Patch6:         scpm-remove_unneeded_typedef.patch
Patch7:         scpm-no_using_in_header.patch
Patch8:         scpm-constification.patch
Patch9:         scpm-doc_config.patch
Patch10:        scpm-md5.patch
Patch11:        scpm-1.1.7-fix-shebang.patch
Requires:       diffutils
Requires:       textutils
Requires(post): awk
Recommends:     logrotate
Suggests:       %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         %insserv_prereq %fillup_prereq %install_info_prereq

%description
SCPM enables your system to save different configurations in profiles.
You can boot directly into a profile as well as switch profiles at run
time. It is the successor of scheme management.


%package        devel
Summary:        Header files and API documentation for SCPM
Group:          Development/Libraries/C and C++
Provides:       scpm:/usr/include/scpm.h
Requires:       %{name} = %{version}

%description devel
This package is only needed if you want to compile applications that
make use of libscpm.


%package        lang
Summary:        Localized messages for scpm
Group:          Development/Libraries/C and C++
Requires:       scpm = %{version}

%description lang
This package contains the localized messages for scpm.

%prep
%setup -q
%patch1 -p0
%patch2
%patch3
%patch4
%patch5 -p1
%patch6
%patch7
%patch8
%patch9
%patch10 -p1
%patch11 -p1

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
echo -e "#!/bin/bash\n$(which %__cxx) \"\$@\"" >g++
chmod 755 g++
export PATH=`pwd`:$PATH
make

%install
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_var}/lib
mkdir -p %{buildroot}%{_prefix}/include
mkdir -p %{buildroot}%{_datadir}/locale/de/LC_MESSAGES
mkdir -p %{buildroot}%{_datadir}/update-messages/en
mkdir -p %{buildroot}%{_defaultdocdir}
mkdir -p %{buildroot}%{_infodir}
mkdir -p %{buildroot}%{_mandir}
mkdir -p %{buildroot}/sbin/conf.d
mkdir -p %{buildroot}/etc/logrotate.d
mkdir -p %{buildroot}/var/adm/fillup-templates
make PREFIX=%{buildroot} EXEC_PREFIX=%{_prefix} install
install -m 755 -d %{buildroot}/%{_defaultdocdir}/scpm
# work around until scpm gets autoconf'd
if [ "%{_lib}" != "lib" ]; then
	mv %{buildroot}%{_prefix}/lib/libscpm* %{buildroot}%{_libdir}
fi
install -m 644 %{SOURCE1} %{buildroot}/etc/logrotate.d/scpm
mkdir -p %{buildroot}/var/log
touch %{buildroot}/var/log/scpm
%find_lang %name

%post
/sbin/ldconfig
%{fillup_and_insserv -y boot.scpm}
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

INITIALIZED=$( scpm status | awk '{ if ($1 == "enabled") print $3 }' )
test $INITIALIZED = no && exit 0

NEEDS_UPDATE=$( scpm status | awk '{ if (($1 == "needs") && ($2 == "reinit")) print $4 }'  )
test $NEEDS_UPDATE  = no && exit 0

TMP=$(mktemp /tmp/scpm_update.XXXXXX)
test -z "$TMP" && TMP=/dev/stdout

scpm -x db set 'status*system' "`head -n 1 /etc/SuSE-release`" > $TMP
scpm -x update_resources > $TMP

test "$TMP" != "/dev/stdout" && rm -f $TMP

%postun
/sbin/ldconfig
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
%{insserv_cleanup}

%files
%defattr(-,root,root)
%config(noreplace) /etc/scpm.users
%config /etc/init.d/boot.scpm
%config /etc/logrotate.d/scpm
%config /etc/bash_completion.d/scpm_completion.sh
%{_sbindir}/scpm
%{_libdir}/libscpm.so.*
%{_prefix}/lib/scpm
%{_mandir}/man8/scpm.8.gz
%{_infodir}/scpm.info.gz
%doc CHANGES README
%dir /var/lib/scpm
%dir /var/lib/scpm/scdb
%dir /var/lib/scpm/profiles
%dir /var/lib/scpm/resource_sets
%dir /var/lib/scpm/resource_groups
%config /var/lib/scpm/active_groups
%config /var/lib/scpm/active_groups
%ghost /var/log/scpm
/var/adm/fillup-templates/sysconfig.scpm

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/libscpm.so
%doc doc/api

%files lang  -f %name.lang
%defattr(-,root,root)

%changelog
* Sun Nov 23 2014 Led <ledest@gmail.com>
- fix shebang in scripts that contains bash-specific constructions
- add patches:
  * scpm-1.1.7-fix-shebang.patch
* Thu Apr 17 2014 crrodriguez@opensuse.org
- Use -fvisiblity-inlines-hidden
- scpm-md5.patch: This is one of the remaining two packages
  that still require abandonware library "mhash", replace
  its usage with cryptopp so we can drop the package in question.
* Wed Sep 12 2012 coolo@suse.com
- add makeinfo as explicit buildrequire
* Thu Jul  5 2012 pth@suse.de
- Remove obsolete buildrequires for lzma.
- Remove the empty %%%%clean line.
* Wed Jul  4 2012 pth@suse.de
- Do the work SuSEconfig.scpm in post and thus get rid of this
  SuSEconfig module (openfate#313547).
- Require awk for post code to work.
- Repackage as xz.
- Don't use 'using namespace' in headers.
- Remove useless typedefs that are ignored.
- Buildrequire graphviz-gnome for png output.
* Fri Sep 30 2011 uli@suse.com
- cross-build workaround: fake g++ script to work around build system
  not honoring CXX
* Fri Jun 17 2011 aj@suse.de
- Fix build due to missing header file (scpm-header.patch).
* Wed Sep 15 2010 pth@suse.de
- Fix makefile to pass library after objects and enable as-needed.
- Create -lang sub package and suggest it.
- Add short description and a do-nothing reload option to
  init script.
- Move .so symlink to devel package.
- Repackage as lzma and don't package CVS subdirs.
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Thu Apr 16 2009 ro@suse.de
- buildfix: refresh patches
* Wed Mar 18 2009 crrodriguez@suse.de
- fix build, do not link with static mhash lib
* Wed Feb 25 2009 crrodriguez@suse.de
- fix build with GCC 44
* Wed Oct 22 2008 helmut.schaa@gmail.com
- update to 1.1.7 final
  * added bash completion (bnc#400354)
  * fix build with gcc 4.3
- remove patch scpm-gcc43.diff
* Mon Aug 18 2008 mrueckert@suse.de
- remove outdated options in the fillup_and_insserv call
- replace deprecated run_ldconfig
* Mon Aug 18 2008 hschaa@suse.de
- Fix boot script again
  (add $null for should-stop and required-stop)
* Wed Aug 13 2008 hschaa@suse.de
-  Fix boot script (Add Should-Stop)
* Sun Jan 13 2008 coolo@suse.de
- fix compilation one more time
* Sat Nov 10 2007 coolo@suse.de
- fix compilation
- mark translations
* Fri Sep 14 2007 jg@suse.de
- update to 1.1.6 final
  * updated translations
* Mon Aug 20 2007 jg@suse.de
-  update to 1.1.6pre2
* Fri Jul 20 2007 jg@suse.de
- added /var/log/scpm as %%ghost to filelist (bug 280463)
- removed ancient 'Obsoletes: schemes' tag
* Mon May 14 2007 jg@suse.de
- update to 1.1.6pre1, changes:
  * fixed support for SuSEfirewall2 service
  * fixed service diff command (bug 249713)
  * fixed init script Should-Start tag, so it gets started
    after local filesystems were mounted (bug 231746)
* Fri Nov 24 2006 jg@suse.de
- fixed postrestore script for /etc/defaultdomain (bug 212920)
* Mon Nov 20 2006 jg@suse.de
- added Russion translations
- updated translations
* Thu Nov  2 2006 jg@suse.de
- fixed Abort on exit when MALLOC_CHECK is enabled
- added /etc/defaultdomain to resource group nis and created a
  postrestore script for it (bug 212920)
- set /etc/printcap and lpd of resource group printer to inactive
  (bug 212918)
* Wed Oct  4 2006 hschaa@suse.de
- update to 1.1.5:
  * integrated check for invalid characters in profile names
* Thu Sep 28 2006 jg@suse.de
- update to 1.1.4:
  * added possibility to restore any backup of a resource,
    not only the latest
  * various backup related fixes
* Fri Aug 11 2006 jg@suse.de
- update to 1.1.4pre1:
  * fixed requires of boot.scpm
  * update file resource excludes
- dropped obsolete scpm.boot-prereq.patch
* Fri Jul 28 2006 olh@suse.de
- boot.scpm requires boot.rootfsck, optional $local_fs (#181972)
* Wed Apr  5 2006 jg@suse.de
- writing boot info after update (bug 159703, this time with
  the right tarball)
* Wed Apr  5 2006 jg@suse.de
- writing boot info after update (bug 159703)
* Wed Apr  5 2006 jg@suse.de
- added section about booting into profiles to texinfo
  documentation (bug 106704)
* Mon Mar 27 2006 jg@suse.de
- updated translations
* Mon Feb 20 2006 jg@suse.de
- updated translations
- fixed patch command (bug 150625)
- ignoring missing file error on profile removal
* Mon Feb  6 2006 jg@suse.de
- ignoring missing file error on profile removal
- fixed wrong file subtype detection on profile import
- fixed temporary files usage (strange permissions and zombies)
- SuSEconfig.scpm: removing temp file on exit (bug 144670)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 13 2005 jg@suse.de
  version 1.1.3pre1
- moved configuration file to /etc/sysconfig/scpm
- Fixed broken profile list output for cases where a profile
  name has more than 20 characters (bug 117760)
* Tue Nov 29 2005 ro@suse.de
- added fontconfig to nfb (for graphviz)
* Thu Sep  1 2005 jg@suse.de
- avoiding usage of system() command as this does not work
  correctly with suid bit set (fixes bug 114788)
* Mon Aug 22 2005 aj@suse.de
- scpm lives now in /usr/sbin [#106246].
* Mon Aug 22 2005 jg@suse.de
- added new translations for ja nb pt pt_BR zh_CN zh_TW
- updated existing translations
* Fri Aug  5 2005 jg@suse.de
- fixed paths in SuSEconfig.scpm
* Sat Jul 23 2005 jg@suse.de
- update to 1.1.2pre2, changes:
  - updated translations templates and German translations
  - fixed faulty diff output for links
  - added French translations
  - fixed wrong handling of empty subdirectories
- moved header files and API documentation into devel subpackage
* Thu Jul  7 2005 schwab@suse.de
- Fix paths in SuSEconfig.scpm.
* Tue Jul  5 2005 jg@suse.de
- fixed installation paths for x86_64 and ppc64
* Fri Jul  1 2005 jg@suse.de
- moved binary and libs to /usr
* Wed Jun 22 2005 jg@suse.de
- added some translations (cs, hu, it, nl, uk)
- fixed diff command for service resource (information for
  runlevel 5 was missing)
* Wed Apr 20 2005 ro@suse.de
- fix build with gcc-4
* Fri Mar 18 2005 jg@suse.de
- fixed diff command for service resource (information for
  runlevel 5 was missing)
* Sat Mar 12 2005 jg@suse.de
- fixed copy command (bug 64220)
- updated translation templates and German translations
* Mon Feb 28 2005 jg@suse.de
- update to 1.1:
  - added resource group lwresd and added it to default active
    groups list (bug 66655)
* Mon Feb 21 2005 jg@suse.de
- update to 1.1pre1:
  - added support for exporting and importing profiles
  - updated German translations
  - more journalized resource group commands
  - showing start/stop priorities on diff command for service
    resources
  - fixed permission problem for diff and patch features
* Mon Nov 15 2004 jg@suse.de
- update to 1.0.1:
  - handling /etc/resolv.conf nicely again
  - cleanups (removal of obsolete scripts)
  - handling now ifservices-directories in /etc/sysconfig/network
  - added postrestore script support for file resources
  - added postrestore script for /etc/HOSTNAME
  - fixed faulty database handling after reenabling scpm
* Fri Oct  1 2004 jg@suse.de
- added workaround for /etc/resolv.conf not getting restored on
  profile restore when coming from a profile using dhcp (bug 46601)
* Thu Sep 30 2004 jg@suse.de
- added resource group smpppd to default groups list (may be needed
  to properly support network device usercontrol feature)
- updated documentation
* Wed Sep 29 2004 jg@suse.de
- fixed progress bar (will be filled to 100%% now on abort)
  (bug 45486)
- fixed a bug in the translation code
- added some missing German translations and updated
  translation template
* Tue Sep 28 2004 jg@suse.de
- fixed enable command (bug 46356)
* Mon Sep 27 2004 jg@suse.de
- updated german translations
- updated translation templates
- fixed copy command
- fixed resource dependency check
- fixed recover command (could abort too early)
- more cleanups
* Mon Sep 20 2004 jg@suse.de
- more fixes for update support
- changed (de)activate resource group library commands to not
  auto-add resp. -remove resources (fixes bug 45600)
- fixed diff command (crashed when not existing resource was given)
- some cleanups
* Thu Sep  9 2004 jg@suse.de
- check for modified resource recognizes changes in file
  attributes now
- added command line option for rollback feature of recover
  command
- fixed rename command
- added journal processing abort option (for testing purposes)
- fixed recover feature for save resource command
- fixed various progress bars for yast2 profile-manager
- fixed diff feature for backup resources
- saving start/stop priority information in database now
  (fixes wrong resource start order)
* Mon Sep  6 2004 jg@suse.de
- update to 1.0:
  - new backup facilities done
  - enabled updating of profile data on system update
  - added rollback functionality to recover system
  - minor bugfixes in progress messages and progress bar output
  - improved error handling on database load failures
  - fixed support for SuSEfirewall2
* Mon Aug 30 2004 jg@suse.de
- update to 1.0pre2:
  - implemented (parts of) new backup mechanism
* Mon Aug 23 2004 jg@suse.de
- update to 1.0pre1:
  - implemented journal
  - added recover command
  - cli exits cleanly now on SIGPIPE (makes piping output of
    scpm possible)
  - code cleanups
* Fri Jun  4 2004 jg@suse.de
- update to 0.9.7:
  - documentation update
  - fixed resource group wwwoffle
  - fixed user name detection for non-root operation
  - added resource groups ldap, nscd, and dhcpd
* Thu May 27 2004 jg@suse.de
- update to 0.9.7pre3:
  - completed SCDB branch-on-demand loading (makes commands like
    'active' or 'list' much faster)
* Mon May 17 2004 jg@suse.de
- update to 0.9.7pre2:
  - fixed broken restore of directories
  - fixed diff function for empty directories
* Tue May 11 2004 jg@suse.de
- update to 0.9.7pre1:
  - removing empty directories in file resources on restore now
  - added support for per-interface-directories in
    /etc/sysconfig/network
  - added database read-only support
  - imporved diff feature a bit
* Tue May  4 2004 jg@suse.de
- fixed grub boot messages support (add/copy/rename/delete commands
  will now update /boo/messages)
* Wed Mar 31 2004 jg@suse.de
- added /etc/logrotate.d/scpm
* Wed Mar 31 2004 jg@suse.de
- updated german translations
- disabled automatic resource update mechanism after system
  update (far too experimental)
- more documentation updates
- backup command fixes
* Mon Mar 22 2004 jg@suse.de
- some documentation updates
- SuSEconfig.scpm status checks fixed (bug #36271)
- boot.scpm aborts now when SCPM is disabled
* Mon Mar 15 2004 jg@suse.de
- fixed broken handling of /etc/sysconfig/network
- calling rcnetwork with -o onboot option, so network
  interfaces marked as manual do not get set up on switch
- fixed broken restore of service resources
* Mon Mar  8 2004 jg@suse.de
- update to 0.9.6
  - added backup remove functions
  - minor fixes in backup mechanism
* Mon Mar  1 2004 jg@suse.de
- update to 0.9.6pre3
  - added backup restore functions
  - implemented missing backup functions
  - implemented support for writing boot informations to
    /boot/message
* Mon Feb 23 2004 jg@suse.de
- update to 0.9.6pre2
  - fixed update script from stdin support
  - script output being put through
  - added notice about resources with backup on restore
* Mon Feb 16 2004 jg@suse.de
- update to 0.9.6pre1
  - partly implemented backup and system update mechanism
  - fix wrong handling of missing /etc/resolv.conf
  - db utility auto loads scdb also in interactive mode now
  - minor documentation fixes
  - added support for writing boot info into /boot/grub/menu.lst
  - added "show resources" command to cli for group mode
  - reduced the probalitity that the scdb file gets destroyed
- added rewritten SuSEconfig.scpm (handles profile updates now)
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig and %%defattr
* Mon Oct  6 2003 jg@suse.de
- update to 0.9.5
  - added alias "remove" for delete command to the frontend
  - allowing execution of list and active commands even
    when SCPM is disabled
* Fri Aug 29 2003 jg@suse.de
- dropped obsolete SuSEconfig.scpm
- added l10n support for diff output
- added l10n support for resource group descriptions
- added German, Czech, and Slovak translations for diff messages
- added German and Czech translations for resource group
  descriptions
* Fri Aug 22 2003 jg@suse.de
- update to 0.9.4
  - added Slovak translations
  - updated Czech translations
  - converted translations to UTF-8
* Mon Aug 11 2003 jg@suse.de
- update to 0.9.4pre4
  - updated documentation
  - updated German translations
  - fixed wrong description parsing in GetResourceGroup
  - ensuring full progress bar even on abort (for YaST2)
* Fri Jul 18 2003 jg@suse.de
- update to 0.9.4pre1
  - fixed get_all scripts to not return inactive resources
  - small fixes in GetResourceGroup and RenameResourceGroup
  - improved error handling on parsing scdb
  - added function to rename resource groups
  - added interface to configuration facilities
* Wed Jun 11 2003 jg@suse.de
- fixed sometimes faulty modification status detection for
  directories
* Tue Jun  3 2003 jg@suse.de
- switch to resource group mode as default
* Fri May 23 2003 jg@suse.de
- update to 0.9.2
  - flushing database directly after switch now (Bug #24995)
  - marking scdb as not modified after writing to prevent double saving
  - added show_group command to command line frontend
  - fixed (de)activate_group commands
  - fixed reading active groups
  - typo fixes
* Thu May  8 2003 jg@suse.de
- update to 0.9.2pre3
  - crash on restoring null resources fixed
  - logging slightly improved
  - some fixes for running scpm as non root
* Wed Apr 30 2003 jg@suse.de
- update to 0.9.2pre2
  - fixed wrong status handling of links
  - added /etc/lpd.perms and /etc/xinet.d/cups-lpd as inactive
    resources to group printer
  - fixed possibly wrong status handling of /etc/resolv.conf
  - added /etc/sysconfig/language to resource set extended
  - added /etc/sysconfig/proxy to resource set typical
  - fixed possibly broken file removal (bug #25396)
  - removing subfiles on file removal now
  - added rebuild command to cli
  - added some debug and info messages
  - fixed possibly wrong detection of modified directories
* Thu Apr 24 2003 ro@suse.de
- merge postuns
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Mar  7 2003 jg@suse.de
- fixed possibly wrong determination of directories' modification
  status (Bug #24846)
* Thu Mar  6 2003 jg@suse.de
- added missing Czech scpm.mo to filelist
* Mon Mar  3 2003 jg@suse.de
- added Czech translations (library part only)
* Mon Feb 24 2003 jg@suse.de
- fixed (sometimes faulty) progress bar output
- fixed sorting incosistency of some scripts
- fixed broken quiet output mode
- partly readded support for external file status handlers
  (needed for proper handling of /etc/resolv.conf)
* Mon Feb 17 2003 jg@suse.de
- Update to 0.9.1
  - improved progress bar output (for yast2)
  - updated german translations
* Thu Feb 13 2003 mmj@suse.de
- Use %%install_info macro [#23455]
* Mon Feb 10 2003 jg@suse.de
- Update to 0.9
  - documentation update (switch command)
  - various fixes in file handling
  - added progress bar facilities for time consuming operations
    (enabling, switching, adding, etc)
  - cli shows now resources only instead of groups in case scpm
    operates in resource group less mode
* Mon Feb  3 2003 jg@suse.de
- Update to 0.9pre3
  - documentation update
  - add auto-add/remove feature for Resource Group (de)activation
* Mon Jan 27 2003 jg@suse.de
- Update to 0.9pre2
  - fixed reload command support
  - fixed broken server active query handler
  - fixed some resource group files
  - aborting now correctly on corrupt resource group files
  - fixed bug in scdb which may prevented a modified scdb from
    beeing written
  - added support for non-root user execution via /etc/scpm.users
  - introduced group 'other' for resources not belonging to a
    group
* Mon Jan 20 2003 jg@suse.de
- Update to 0.9pre1
  - added resource group support
  - storage system completely rewritten, is now integrated into
    the SCDB
  - service resource has now external handles for active state
    detection and restoration
  - improved switch script support
  - added "get all" command
  - added locking support
  - documentation update (new features, typo fixes)
* Wed Sep 11 2002 jg@suse.de
- Added service cups to default resource set 'typical'
- Improved support for cups
* Mon Sep  9 2002 jg@suse.de
- Fixed a fatal bug in storage module
* Fri Sep  6 2002 jg@suse.de
- Fixed building on x86-64
- Fixed a nasty bug in directory handling
* Thu Sep  5 2002 jg@suse.de
- Replaced the introduction of the info documentation with
  the proof read version
- Set verbose mode as default
- Splitted /etc/sysconfig/network resource, scripts
  under /etc/sysconfig/network/if-{up|down}.d supported now
- Linking libmhash static now (means, /usr on nfs should be
  finally supported)
- Minor translation fixes
* Mon Sep  2 2002 jg@suse.de
- Fixed status detection issues with /etc/resolv.conf
* Tue Aug 27 2002 jg@suse.de
- Fixed building on 64bit platforms
* Mon Aug 26 2002 jg@suse.de
- Added compatibility link /usr/%%{_lib}/libscpm.so
- Changed acronym meaning of SCPM to System Configuration
  Profile Management
- Extended Introduction in info documentation
- Fixed possible segfault in ShowChanges function
- Added resource sets extended and network_only
- Added /etc/hosts to resource set typical
* Tue Aug 20 2002 jg@suse.de
- Added PreReq tag
* Fri Aug 16 2002 jg@suse.de
- changed version number to 0.8
- Permissions and uid/gid get now restored correctly
- Added new resource set "everything"
- Added postfix stuff to resource set "typical"
- Fixed a bug in get_files script
- Added faked progress bar for YaST2 frontend
* Fri Aug  9 2002 jg@suse.de
- new version 0.8pre4, from CHANGES file:
  - Made translation routine more robust
  - Fixed a small translation bug
  - Added more german translations
  - Minor documentation updates
  - SWITCH_MODE variable has now the wanted effects
  - service postfix is now supported correctly
* Wed Aug  7 2002 jg@suse.de
- new version 0.8pre3, from CHANGES file:
  - Added VERBOSE variable to scpm.conf
  - Added localization features and german translations
  - Using compiler switch -g now only when no CXXFLAGS are given
  - Improved logging messages
  - Added verbose progress messages
  - Fixed a bug with the switch_info struct
  - Some code cleanups
  - Fixed a bug in SuSEconfig.scpm
* Fri Aug  2 2002 jg@suse.de
- new version 0.8pre2, from CHANGES file:
  - Update mechanism to SCDB v1.2 implemented
  - Added comments to scpm.conf template
  - Added DEBUG and SWITCH_MODE variables to scpm.conf
  - Fixed service_get_deps script to work with SL 8.1
  - Improved Resource Set handling
  - Removed sysconfig resource type
  - Fixed scdb to not abort with uncaught exceptions anymore
  - Generating usable specfile now instead of providing a
  static and always outdated one
- Added /sbin/conf.d/SuSEconfig.scpm to filelist
- Removed xf86 from neededforbuild
- Removed unneccesary cp command from specfile
* Thu Jul 25 2002 jg@suse.de
- new version 0.8pre1, from CHANGES file:
  - Documented "get"
  - Added localization facilities (still no translations, of course)
  - Implemented ShowChanges(), only File resource supports this ATM
  - Add 'diff' command to cli as standalone command and embedded
    in the switch process
  - Added RebuildDB()
  - Added profile description output to list command
    (suppressable with '-n')
  - Added optional force flag to Enable function
  - Rewrote File resource type to handle directories, making sysonfig
    resource type obsolete
  - Fixed wrong iostream handling in storage module, should now
    run in gcc 3.1 environment
  - Broken md5sum generation fixed
- added /usr/include and /usr/share/locale stuff to specfile
- added dependency to diffutils in specfile
* Mon Jul 22 2002 jg@suse.de
- update to 0.7.2 which fixes a bug in scpm reinitialization
* Mon Jul 15 2002 jg@suse.de
- update to final 0.7.1
- fixed possible failure on Add/Copy operations
- added CHANGES and README to package documentation
* Sun Jul 14 2002 jg@suse.de
- Fixed another /lib64 issue
* Fri Jul 12 2002 jg@suse.de
- update to actual CVS version of 0.7.1, from CHANGES file:
  - Added optional auto_switch parameter to the 'Add' function
  - Introduction chapter added to texinfo documentation
  - Changed Save function, needs PrepareSwitch as prerequisite
  - Updated cli to incorporate API changes
  - Possibly wrong profile clean status in database fixed
  - Implemented Get/Set/List/ResourceSet(s) functions
  - Added /etc/scpm.conf writing feature to SCPM_conf
  - Using md5 sums of rpm db and resource set file for system
    magic generation now
  - Fixed code to compile with gcc 3.1
  - Added -fPIC compiler switch
- see CHANGES file for older changes
* Thu Jun 27 2002 ro@suse.de
- fix neededforbuild
  (don't try to link static libmhash into shared lib)
* Sun May 19 2002 schwab@suse.de
- Fix building of shared library.
* Mon May 13 2002 jg@suse.de
- modified specfile to support /lib64 library location on
  64bit architectures
- using RPM_OPT_FLAGS now
* Mon May 13 2002 jg@suse.de
- new version 0.6.4: incorporates minor fixes from 0.6.3
  and ro's gcc-3.1 changes
- uses buildroot now
* Fri May 10 2002 ro@suse.de
- build with gcc-3.1
* Thu Mar 14 2002 jg@suse.de
- Fixed some typos and bad expressions in the man page
* Thu Mar 14 2002 jg@suse.de
- Fixed handling of stored profile data (gets removed now
  on profile deletion)
- Cosmetical fixes in log messages and help text
- Fixed file resource get_all script to always honor extra entries
* Tue Mar 12 2002 jg@suse.de
- fixed return values of boot.scpm to match LSB
- made command line interface honor the -f and -s switch
- fixed command line interface to show help on -h and --help
* Wed Mar  6 2002 jg@suse.de
- fixed resource start/stop ordering
- added missing sysconfig_post_restore_isdn script
- updated documentation (using texinfo now)
* Mon Mar  4 2002 jg@suse.de
- Update to version 0.6.2 (bugfix release), which mainly
  fixes bugs in the sysconfig resource type, in
  resource start/stop handling, and in the logging mechanism
* Mon Feb 25 2002 jg@suse.de
- Update to version 0.6.1 including various fixes
  for the command line UI and the boot mode
- Added missing /etc/init.d/boot.scpm to specfile
* Mon Feb 11 2002 jg@suse.de
- Update to test version 0.6 (incorporates all basic features now)
* Fri Jan 18 2002 jg@suse.de
- Update to test version 0.5
* Fri Jan 11 2002 jg@suse.de
- Update to test version 0.4
- Included API documentation
* Thu Dec 20 2001 jg@suse.de
- Update to version 0.3 (experimental release)
* Mon Jul 23 2001 jg@suse.de
- First Version (does still use 'schemes' as backend)
